@@ -9,7 +9,7 @@ use File::Temp qw(tempfile);
 use Carp::Assert;
 
 BEGIN {
-    system("which gnuplot") == 0 || die 'Gnuplot was not found from $PATH using which.';
+    system("which gnuplot > /dev/null") == 0 || die 'Gnuplot was not found from $PATH using which.';
 }
 
 #ABSTRACT   Gnuplot::Simple - A simple way to control Gnuplot
@@ -23,7 +23,7 @@ Gnuplot::Simple - A simple way to control Gnuplot
 Gnuplot can be controlled from Perl using a pipe. This modules faciliates the process
 to allow more convenient graph plotting from perl e.g.
 
-  use GnuPlot::Simple qw(write_data);
+  use Gnuplot::Simple qw(write_data);
 
   write_data("file.txt", [[ 1,2 ],[ 2,3 ]] );
 
@@ -40,10 +40,11 @@ Each element in $dataset should be of the form [[<c1>...<cn>],...]
 
 The column values must not contain newlines (\n or \r) or quote marks. They can be non-ascii unicode.
 
-=head2 func exec_commands ($c, $data)
+=head2 func exec_commands ($c, $data, $placeholder = "__DATA__")
 
 Example usage:
 
+    use Gnuplot::Simple qw(exec_commands);
     my $d = [ [ 1,2 ],[ 2,3 ] ];
     exec_commands(
         qq{
@@ -55,7 +56,7 @@ Example usage:
 
 The function takes a string of gnuplot commands $c that is piped to gnuplot. You can give a data set as well in the array ref $data.
 Then, any occurences of __DATA__ in $c are replaced by a temp file containing $data transformed to gnuplot format as
-done by write_data.
+done by write_data. The placeholder __DATA__ can be changed via the last parameter.
 
 The function throws the gnuplot error message if execution fails. 
 
@@ -88,8 +89,7 @@ func _transform ( ArrayRef $data) {
     join( "\n", map { $csv->combine(@$_); $csv->string(); } @$data );
 }
 
-#@data refers to the possibility of multiple data sets, which has not been implemented yet.
-func exec_commands ( Str $c, @data ) {
+func exec_commands ( Str $c, $data, $placeholder = "__DATA__" ) {
 
     my ( $eh, $errfile ) = tempfile();
 
@@ -97,13 +97,13 @@ func exec_commands ( Str $c, @data ) {
 
     my $tmp = File::Temp->new();
     my $tfn = $tmp->filename();
-    write_data( $tfn, @data );
+    write_data( $tfn, $data );
 
     #use placeholder to replace all occurences
-    $c =~ s/__DATA__/'$tfn'/g;
+    $c =~ s/$placeholder/'$tfn'/g;
 
     binmode $proc, ":utf8";
-    ( print $proc $c ) or die "Failed to input commands to gnuplot.";
+    ( print $proc $c ) or die "Failed to input commands to gnuplot: $!";
 
     close $proc;
 
